Documentation
¶
Overview ¶
Package nntp provides base NNTP definitions.
Index ¶
Constants ¶
const ( Unknown = PostingStatus(0) PostingPermitted = PostingStatus('y') PostingNotPermitted = PostingStatus('n') PostingModerated = PostingStatus('m') )
PostingStatus values.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Article ¶
type Article struct {
// The article's headers
Header textproto.MIMEHeader
// The article's body
Body io.Reader
// Number of bytes in the article body (used by OVER/XOVER)
Bytes int
// Number of lines in the article body (used by OVER/XOVER)
Lines int
}
An Article that may appear in one or more groups.
type Group ¶
type Group struct {
Name string
Description string
Count int64
High int64
Low int64
Posting PostingStatus
}
Group represents a usenet newsgroup.
type PostingStatus ¶
type PostingStatus byte
PostingStatus type for groups.
func (PostingStatus) String ¶
func (ps PostingStatus) String() string
Directories
¶
| Path | Synopsis |
|---|---|
|
Package nntpclient provides an NNTP Client.
|
Package nntpclient provides an NNTP Client. |
|
examples
|
|
|
client
command
|
|
|
couchserver
command
|
|
|
couchserver/groupcreator
command
|
|
|
server
command
|
|
|
Package nntpserver provides everything you need for your own NNTP server.
|
Package nntpserver provides everything you need for your own NNTP server. |
Click to show internal directories.
Click to hide internal directories.